==> pipewire-docs-1%3A0.3.70-2-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/group__pw__stream.js <==
var group__pw__stream =
[
    [ "stream.h", "stream_8h.html", null ],
    [ "pw_buffer", "structpw__buffer.html", [
      [ "buffer", "structpw__buffer.html#ad0716b5bc3f7e1cb3009c524c0192090", null ],
      [ "user_data", "structpw__buffer.html#ad85549808ad885c57f85e1aee60b8c96", null ],
      [ "size", "structpw__buffer.html#a925734b861209896789573f3b94a61c1", null ],
      [ "requested", "structpw__buffer.html#ab5fe741ec31686febdbc602098945f08", null ]
    ] ],
    [ "pw_stream_control", "structpw__stream__control.html", [
      [ "flags", "structpw__stream__control.html#a4167f3df47a2d2deff793d3f1f6d31d2", null ],
      [ "def", "structpw__stream__control.html#a4541b454ba4caaf23f4e772f431294c1", null ],
      [ "min", "structpw__stream__control.html#a61f6208ade53511ac42e01185f270f62", null ],
      [ "max", "structpw__stream__control.html#a40b47654929367a6a4f1b83b0b68bfb1", null ],
      [ "values", "structpw__stream__control.html#addabfd3b77bb0cb58bb65b779ab1b3d5", null ],
      [ "n_values", "structpw__stream__control.html#a925311b76a91a9034391da7343865091", null ],
      [ "max_values", "structpw__stream__control.html#a4ffcfbdb7762b0650a28f10eb8c10046", null ]
    ] ],
    [ "pw_time", "structpw__time.html", [
      [ "now", "structpw__time.html#ad817da21bea1591d70f837c251a73468", null ],
      [ "rate", "structpw__time.html#a41d793c390eefc6aee165e16e0d7c898", null ],
      [ "ticks", "structpw__time.html#a99e3d7963e24fbf410afa03c73465328", null ],
      [ "delay", "structpw__time.html#a1ea3fa77ce4221df0d5ac3ad8fd1f6c7", null ],
      [ "queued", "structpw__time.html#a91dafbb38397328f8705e2bb20b7625a", null ],
      [ "buffered", "structpw__time.html#a4ad8ba0afa44dc283d8ecd5ea1e9d0ff", null ],
      [ "queued_buffers", "structpw__time.html#a92d7a1849d4dc044d2fa64bd35a7a57d", null ],
      [ "avail_buffers", "structpw__time.html#aebd42745267531bc23e1ee34dd759607", null ]
    ] ],
    [ "pw_stream_events", "structpw__stream__events.html", [
      [ "version", "structpw__stream__events.html#a74aaca4c31e44dad69aba50607055419", null ],
      [ "destroy", "structpw__stream__events.html#abbe98bb0d78e6411d08244495f349b0b", null ],
      [ "state_changed", "structpw__stream__events.html#a89192aed5fcd89314bf7cc7ef6b21085", null ],
      [ "control_info", "structpw__stream__events.html#a12fa5918ff2c41cc41d5bf8ae36b3ca3", null ],
      [ "io_changed", "structpw__stream__events.html#ad60b819ff0ea17b0bd8833220cbd4a3e", null ],
      [ "param_changed", "structpw__stream__events.html#a4d1ed03aa78fb2c8324ae13bc45731e3", null ],
      [ "add_buffer", "structpw__stream__events.html#abd09d7c76b0e14a201a438f09e609b29", null ],
      [ "remove_buffer", "structpw__stream__events.html#a0cdc45fef5f2458a0fd11a6e9ef1f6fb", null ],
      [ "process", "structpw__stream__events.html#a512bd219ce44ba1a688d600773efe84b", null ],
      [ "drained", "structpw__stream__events.html#aab4b9831ef563920b401b1f9daf93042", null ],
      [ "command", "structpw__stream__events.html#a66e43e35eb2be261520cda8a4e24098c", null ],
      [ "trigger_done", "structpw__stream__events.html#a1de8432b45484bc0e060162b78720c02", null ]
    ] ],
    [ "pw_stream", "structpw__stream.html", null ],
    [ "PW_VERSION_STREAM_EVENTS", "group__pw__stream.html#gaf21c1b002f78067d2eca97c455970822", null ],
    [ "pw_stream_state", "group__pw__stream.html#ga9ceaca6fc9acd9a1af080258d763fb82", [
      [ "PW_STREAM_STATE_ERROR", "group__pw__stream.html#gga9ceaca6fc9acd9a1af080258d763fb82aae3c1d061da27957fd3a9389b29ff89e", null ],
      [ "PW_STREAM_STATE_UNCONNECTED", "group__pw__stream.html#gga9ceaca6fc9acd9a1af080258d763fb82aae02f4af09cb65c931e95e1aa3bdd5f3", null ],
      [ "PW_STREAM_STATE_CONNECTING", "group__pw__stream.html#gga9ceaca6fc9acd9a1af080258d763fb82a775f5777259aa54f7ad6d4c7cfa1779f", null ],
      [ "PW_STREAM_STATE_PAUSED", "group__pw__stream.html#gga9ceaca6fc9acd9a1af080258d763fb82a0537b5f9f722fb2faf7822cd09370825", null ],
      [ "PW_STREAM_STATE_STREAMING", "group__pw__stream.html#gga9ceaca6fc9acd9a1af080258d763fb82af3c3b39039810d40a7c9e1ae3c6c905d", null ]
    ] ],
    [ "pw_stream_flags", "group__pw__stream.html#ga058907c2dffbb8fb5ede8a53d7604106", [
      [ "PW_STREAM_FLAG_NONE", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106aefcc7a31a05fa55c8cff7e686dd484ca", null ],
      [ "PW_STREAM_FLAG_AUTOCONNECT", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106ab648fa0c0c7adf6aa3139eddc3a9cd7c", null ],
      [ "PW_STREAM_FLAG_INACTIVE", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106a2912e7520b8eb0aa5e4a5ca275f10d3b", null ],
      [ "PW_STREAM_FLAG_MAP_BUFFERS", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106a615348212b647ad5d30313536ed6e125", null ],
      [ "PW_STREAM_FLAG_DRIVER", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106a73692ffb4a18142df04772cf3783410c", null ],
      [ "PW_STREAM_FLAG_RT_PROCESS", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106ad569b3a7085e21df1236651fd3388a22", null ],
      [ "PW_STREAM_FLAG_NO_CONVERT", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106a87c6bfacd40d4f797505fbc22bd2b9da", null ],
      [ "PW_STREAM_FLAG_EXCLUSIVE", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106a79f1bdb249e79c7e71cf46759936768f", null ],
      [ "PW_STREAM_FLAG_DONT_RECONNECT", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106ab111b3fc3e1d3c1c439a65dc85a3ce20", null ],
      [ "PW_STREAM_FLAG_ALLOC_BUFFERS", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106ab95a612ea82e3d928b5d2971bcd96465", null ],
      [ "PW_STREAM_FLAG_TRIGGER", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106a8dcfd7b1a9bd963ded7523bc0f01d376", null ]
    ] ],
    [ "pw_stream_state_as_string", "group__pw__stream.html#ga8b023e0bc564e4e8f70cec17e7c608f4", null ],
    [ "pw_stream_new", "group__pw__stream.html#ga712ca485dc634252d144556074980f0a", null ],
    [ "pw_stream_new_simple", "group__pw__stream.html#gacdd761aac33011a41d1f05cfe9effb11", null ],
    [ "pw_stream_destroy", "group__pw__stream.html#gaf48f79b09798488557cd6c2f896e0891", null ],
    [ "pw_stream_add_listener", "group__pw__stream.html#gadfa74620109228a9cfce24b628aa130f", null ],
    [ "pw_stream_get_state", "group__pw__stream.html#ga087a686c66c04e54742cc94c7a5e4e68", null ],
    [ "pw_stream_get_name", "group__pw__stream.html#gaca974f99f4545ce623a94c2f06a48dd0", null ],
    [ "pw_stream_get_core", "group__pw__stream.html#gaf98d3941e1f3343c61dc218296eb8942", null ],
    [ "pw_stream_get_properties", "group__pw__stream.html#gad9606e2efb479a55ee798f61b82aa49b", null ],
    [ "pw_stream_update_properties", "group__pw__stream.html#ga065b067d55def0d2c2cedf814a5c55d0", null ],
    [ "pw_stream_connect", "group__pw__stream.html#ga0e12176f13e654e64e7f5689e7a6dd54", null ],
    [ "pw_stream_get_node_id", "group__pw__stream.html#ga1744b8f160ac0f8d377db9bfdab57053", null ],
    [ "pw_stream_disconnect", "group__pw__stream.html#gaa727d7a41acb9d0ec574f93f01328d30", null ],
    [ "pw_stream_set_error", "group__pw__stream.html#ga19f542ff2b8a51336ae78cfaec8ed896", null ],
    [ "pw_stream_update_params", "group__pw__stream.html#ga0c274f28a9b9b2fe286719db159f166b", null ],
    [ "pw_stream_set_param", "group__pw__stream.html#ga97c613bc4ea822bfbbce0de6ab1b9042", null ],
    [ "pw_stream_get_control", "group__pw__stream.html#ga8a3e7ddb0e61c4266ce735a085adb5e7", null ],
    [ "pw_stream_set_control", "group__pw__stream.html#ga2d5e07833039ac7a202caaf297556f52", null ],
    [ "pw_stream_get_time_n", "group__pw__stream.html#gadde95a60798bfffa6575306bc07ee7f4", null ],
    [ "pw_stream_get_time", "group__pw__stream.html#ga721dc4d5ec4c406ecb0469bfefea468f", null ],
    [ "pw_stream_dequeue_buffer", "group__pw__stream.html#ga0ed34dd74ca8f5f46db7c2a4cbd45a94", null ],
    [ "pw_stream_queue_buffer", "group__pw__stream.html#gabe1c593f34080ea9c8c6231abe4e7386", null ],
    [ "pw_stream_set_active", "group__pw__stream.html#gaafa1055c167dd99ba94bb49ec30603ba", null ],
    [ "pw_stream_flush", "group__pw__stream.html#ga5ef987fd1903baa7eba9b10a8cbf5e97", null ],
    [ "pw_stream_is_driving", "group__pw__stream.html#ga3ddd332c45aa95250d3d1d26cf01452a", null ],
    [ "pw_stream_trigger_process", "group__pw__stream.html#gab93fa91d8ea80e562bb5e8f6b5bafe21", null ]
];

==> pipewire-docs-1%3A0.3.84-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/group__pw__stream.js <==
var group__pw__stream =
[
    [ "stream.h", "stream_8h.html", null ],
    [ "pw_buffer", "structpw__buffer.html", [
      [ "buffer", "structpw__buffer.html#ad0716b5bc3f7e1cb3009c524c0192090", null ],
      [ "user_data", "structpw__buffer.html#ad85549808ad885c57f85e1aee60b8c96", null ],
      [ "size", "structpw__buffer.html#a925734b861209896789573f3b94a61c1", null ],
      [ "requested", "structpw__buffer.html#ab5fe741ec31686febdbc602098945f08", null ]
    ] ],
    [ "pw_stream_control", "structpw__stream__control.html", [
      [ "flags", "structpw__stream__control.html#a4167f3df47a2d2deff793d3f1f6d31d2", null ],
      [ "def", "structpw__stream__control.html#a4541b454ba4caaf23f4e772f431294c1", null ],
      [ "min", "structpw__stream__control.html#a61f6208ade53511ac42e01185f270f62", null ],
      [ "max", "structpw__stream__control.html#a40b47654929367a6a4f1b83b0b68bfb1", null ],
      [ "values", "structpw__stream__control.html#addabfd3b77bb0cb58bb65b779ab1b3d5", null ],
      [ "n_values", "structpw__stream__control.html#a925311b76a91a9034391da7343865091", null ],
      [ "max_values", "structpw__stream__control.html#a4ffcfbdb7762b0650a28f10eb8c10046", null ]
    ] ],
    [ "pw_time", "structpw__time.html", [
      [ "now", "structpw__time.html#ad817da21bea1591d70f837c251a73468", null ],
      [ "rate", "structpw__time.html#a41d793c390eefc6aee165e16e0d7c898", null ],
      [ "ticks", "structpw__time.html#a99e3d7963e24fbf410afa03c73465328", null ],
      [ "delay", "structpw__time.html#a1ea3fa77ce4221df0d5ac3ad8fd1f6c7", null ],
      [ "queued", "structpw__time.html#a91dafbb38397328f8705e2bb20b7625a", null ],
      [ "buffered", "structpw__time.html#a4ad8ba0afa44dc283d8ecd5ea1e9d0ff", null ],
      [ "queued_buffers", "structpw__time.html#a92d7a1849d4dc044d2fa64bd35a7a57d", null ],
      [ "avail_buffers", "structpw__time.html#aebd42745267531bc23e1ee34dd759607", null ]
    ] ],
    [ "pw_stream_events", "structpw__stream__events.html", [
      [ "version", "structpw__stream__events.html#a74aaca4c31e44dad69aba50607055419", null ],
      [ "destroy", "structpw__stream__events.html#abbe98bb0d78e6411d08244495f349b0b", null ],
      [ "state_changed", "structpw__stream__events.html#a89192aed5fcd89314bf7cc7ef6b21085", null ],
      [ "control_info", "structpw__stream__events.html#a12fa5918ff2c41cc41d5bf8ae36b3ca3", null ],
      [ "io_changed", "structpw__stream__events.html#ad60b819ff0ea17b0bd8833220cbd4a3e", null ],
      [ "param_changed", "structpw__stream__events.html#a4d1ed03aa78fb2c8324ae13bc45731e3", null ],
      [ "add_buffer", "structpw__stream__events.html#abd09d7c76b0e14a201a438f09e609b29", null ],
      [ "remove_buffer", "structpw__stream__events.html#a0cdc45fef5f2458a0fd11a6e9ef1f6fb", null ],
      [ "process", "structpw__stream__events.html#a512bd219ce44ba1a688d600773efe84b", null ],
      [ "drained", "structpw__stream__events.html#aab4b9831ef563920b401b1f9daf93042", null ],
      [ "command", "structpw__stream__events.html#a66e43e35eb2be261520cda8a4e24098c", null ],
      [ "trigger_done", "structpw__stream__events.html#a1de8432b45484bc0e060162b78720c02", null ]
    ] ],
    [ "pw_stream", "structpw__stream.html", null ],
    [ "PW_VERSION_STREAM_EVENTS", "group__pw__stream.html#gaf21c1b002f78067d2eca97c455970822", null ],
    [ "pw_stream_state", "group__pw__stream.html#ga9ceaca6fc9acd9a1af080258d763fb82", [
      [ "PW_STREAM_STATE_ERROR", "group__pw__stream.html#gga9ceaca6fc9acd9a1af080258d763fb82aae3c1d061da27957fd3a9389b29ff89e", null ],
      [ "PW_STREAM_STATE_UNCONNECTED", "group__pw__stream.html#gga9ceaca6fc9acd9a1af080258d763fb82aae02f4af09cb65c931e95e1aa3bdd5f3", null ],
      [ "PW_STREAM_STATE_CONNECTING", "group__pw__stream.html#gga9ceaca6fc9acd9a1af080258d763fb82a775f5777259aa54f7ad6d4c7cfa1779f", null ],
      [ "PW_STREAM_STATE_PAUSED", "group__pw__stream.html#gga9ceaca6fc9acd9a1af080258d763fb82a0537b5f9f722fb2faf7822cd09370825", null ],
      [ "PW_STREAM_STATE_STREAMING", "group__pw__stream.html#gga9ceaca6fc9acd9a1af080258d763fb82af3c3b39039810d40a7c9e1ae3c6c905d", null ]
    ] ],
    [ "pw_stream_flags", "group__pw__stream.html#ga058907c2dffbb8fb5ede8a53d7604106", [
      [ "PW_STREAM_FLAG_NONE", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106aefcc7a31a05fa55c8cff7e686dd484ca", null ],
      [ "PW_STREAM_FLAG_AUTOCONNECT", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106ab648fa0c0c7adf6aa3139eddc3a9cd7c", null ],
      [ "PW_STREAM_FLAG_INACTIVE", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106a2912e7520b8eb0aa5e4a5ca275f10d3b", null ],
      [ "PW_STREAM_FLAG_MAP_BUFFERS", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106a615348212b647ad5d30313536ed6e125", null ],
      [ "PW_STREAM_FLAG_DRIVER", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106a73692ffb4a18142df04772cf3783410c", null ],
      [ "PW_STREAM_FLAG_RT_PROCESS", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106ad569b3a7085e21df1236651fd3388a22", null ],
      [ "PW_STREAM_FLAG_NO_CONVERT", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106a87c6bfacd40d4f797505fbc22bd2b9da", null ],
      [ "PW_STREAM_FLAG_EXCLUSIVE", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106a79f1bdb249e79c7e71cf46759936768f", null ],
      [ "PW_STREAM_FLAG_DONT_RECONNECT", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106ab111b3fc3e1d3c1c439a65dc85a3ce20", null ],
      [ "PW_STREAM_FLAG_ALLOC_BUFFERS", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106ab95a612ea82e3d928b5d2971bcd96465", null ],
      [ "PW_STREAM_FLAG_TRIGGER", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106a8dcfd7b1a9bd963ded7523bc0f01d376", null ],
      [ "PW_STREAM_FLAG_ASYNC", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106a87bea1e205976ef478faed4d9a113576", null ],
      [ "PW_STREAM_FLAG_EARLY_PROCESS", "group__pw__stream.html#gga058907c2dffbb8fb5ede8a53d7604106a1496d5f5dd44faa078d2949463292775", null ]
    ] ],
    [ "pw_stream_state_as_string", "group__pw__stream.html#ga8b023e0bc564e4e8f70cec17e7c608f4", null ],
    [ "pw_stream_new", "group__pw__stream.html#ga712ca485dc634252d144556074980f0a", null ],
    [ "pw_stream_new_simple", "group__pw__stream.html#gacdd761aac33011a41d1f05cfe9effb11", null ],
    [ "pw_stream_destroy", "group__pw__stream.html#gaf48f79b09798488557cd6c2f896e0891", null ],
    [ "pw_stream_add_listener", "group__pw__stream.html#gadfa74620109228a9cfce24b628aa130f", null ],
    [ "pw_stream_get_state", "group__pw__stream.html#ga087a686c66c04e54742cc94c7a5e4e68", null ],
    [ "pw_stream_get_name", "group__pw__stream.html#gaca974f99f4545ce623a94c2f06a48dd0", null ],
    [ "pw_stream_get_core", "group__pw__stream.html#gaf98d3941e1f3343c61dc218296eb8942", null ],
    [ "pw_stream_get_properties", "group__pw__stream.html#gad9606e2efb479a55ee798f61b82aa49b", null ],
    [ "pw_stream_update_properties", "group__pw__stream.html#ga065b067d55def0d2c2cedf814a5c55d0", null ],
    [ "pw_stream_connect", "group__pw__stream.html#ga0e12176f13e654e64e7f5689e7a6dd54", null ],
    [ "pw_stream_get_node_id", "group__pw__stream.html#ga1744b8f160ac0f8d377db9bfdab57053", null ],
    [ "pw_stream_disconnect", "group__pw__stream.html#gaa727d7a41acb9d0ec574f93f01328d30", null ],
    [ "pw_stream_set_error", "group__pw__stream.html#ga19f542ff2b8a51336ae78cfaec8ed896", null ],
    [ "pw_stream_update_params", "group__pw__stream.html#ga0c274f28a9b9b2fe286719db159f166b", null ],
    [ "pw_stream_set_param", "group__pw__stream.html#ga97c613bc4ea822bfbbce0de6ab1b9042", null ],
    [ "pw_stream_get_control", "group__pw__stream.html#ga8a3e7ddb0e61c4266ce735a085adb5e7", null ],
    [ "pw_stream_set_control", "group__pw__stream.html#ga2d5e07833039ac7a202caaf297556f52", null ],
    [ "pw_stream_get_time_n", "group__pw__stream.html#gadde95a60798bfffa6575306bc07ee7f4", null ],
    [ "pw_stream_get_time", "group__pw__stream.html#ga721dc4d5ec4c406ecb0469bfefea468f", null ],
    [ "pw_stream_dequeue_buffer", "group__pw__stream.html#ga0ed34dd74ca8f5f46db7c2a4cbd45a94", null ],
    [ "pw_stream_queue_buffer", "group__pw__stream.html#gabe1c593f34080ea9c8c6231abe4e7386", null ],
    [ "pw_stream_set_active", "group__pw__stream.html#gaafa1055c167dd99ba94bb49ec30603ba", null ],
    [ "pw_stream_flush", "group__pw__stream.html#ga5ef987fd1903baa7eba9b10a8cbf5e97", null ],
    [ "pw_stream_is_driving", "group__pw__stream.html#ga3ddd332c45aa95250d3d1d26cf01452a", null ],
    [ "pw_stream_trigger_process", "group__pw__stream.html#gab93fa91d8ea80e562bb5e8f6b5bafe21", null ]
];
